@@ -4,9 +4,7 @@ import tempfile
 import os
 
 from bincrafters.build_shared import printer, get_os
-import bincrafters.build_template_default as build_template_default
-import bincrafters.build_template_header_only as build_template_header_only
-import bincrafters.build_template_installer as build_template_installer
+from bincrafters import build_shared
 from bincrafters.autodetect import *
 
 
@@ -15,6 +13,73 @@ def _flush_output():
     sys.stdout.flush()
 
 
+def _get_default_builder(shared_option_name=None,
+                    pure_c=True,
+                    dll_with_static_runtime=False,
+                    build_policy=None,
+                    cwd=None,
+                    reference=None,
+                    **kwargs):
+    recipe = build_shared.get_recipe_path(cwd)
+
+    builder = build_shared.get_builder(build_policy, cwd=cwd, **kwargs)
+    if shared_option_name is None and build_shared.is_shared():
+        shared_option_name = "%s:shared" % build_shared.get_name_from_recipe(recipe=recipe)
+
+    builder.add_common_builds(
+        shared_option_name=shared_option_name,
+        pure_c=pure_c,
+        dll_with_static_runtime=dll_with_static_runtime,
+        reference=reference)
+
+    return builder
+
+
+def _get_builder():
+    ###
+    # Output collected recipe information in the builds logs
+    ###
+    recipe_is_installer = is_installer()
+    printer.print_message("Is the package an installer for executable(s)? {}"
+                          .format(str(recipe_is_installer)))
+
+    if not recipe_is_installer:
+        recipe_is_unconditional_header_only = is_unconditional_header_only()
+        printer.print_message("Is the package header only? {}"
+                              .format(str(recipe_is_unconditional_header_only)))
+
+        if not recipe_is_unconditional_header_only:
+            recipe_is_conditional_header_only = is_conditional_header_only()
+            printer.print_message("Is the package conditionally header only ('header_only' option)? {}"
+                                  .format(str(recipe_is_conditional_header_only)))
+
+            recipe_is_pure_c = is_pure_c()
+            printer.print_message("Is the package C-only? {}".format(str(recipe_is_pure_c)))
+
+    _flush_output()
+
+    ###
+    # Create builder
+    ###
+    kwargs = {}
+
+    if autodetect_directory_structure() == DIR_STRUCTURE_ONE_RECIPE_MANY_VERSIONS \
+            or autodetect_directory_structure() == DIR_STRUCTURE_CCI:
+        kwargs["stable_branch_pattern"] = os.getenv("CONAN_STABLE_BRANCH_PATTERN", "main")
+
+    if recipe_is_installer:
+        arch = os.getenv("ARCH", "x86_64")
+        builder = build_shared.get_builder(**kwargs)
+        builder.add({"os": get_os(), "arch_build": arch, "arch": arch}, {}, {}, {})
+    elif recipe_is_unconditional_header_only:
+        builder = build_shared.get_builder(**kwargs)
+        builder.add()
+    else:
+        builder = _get_default_builder(pure_c=recipe_is_pure_c, **kwargs)
+
+    return builder
+
+
 def run_autodetect():
     ###
     # Enabling Conan download cache
@@ -27,17 +92,34 @@ def run_autodetect():
     # In some cases Python may ignore the mode of makedirs, do it again explicitly with chmod
     os.chmod(tmpdir, mode=0o777)
 
-    os.system('conan config set storage.download_cache="{}"'.format(tmpdir))
-    os.system('conan config set general.revisions_enabled=1')
-    os.environ["CONAN_DOCKER_ENTRY_SCRIPT"] =\
-        "conan config set storage.download_cache='{}'; conan config set general.revisions_enabled=1".format(tmpdir)
-    os.environ["CONAN_DOCKER_RUN_OPTIONS"] = "-v '{}':'/tmp/conan'".format(tmpdir)
-
-    ###
-    # Enabling installing system_requirements
-    ###
+    # Setting values for global.conf - Recipes (behaviour) configs
     os.environ["CONAN_SYSREQUIRES_MODE"] = "enabled"
 
+    conan_global_conf = os.environ.get("CONAN_GLOBAL_CONF", '')
+    if conan_global_conf:
+        conan_global_conf += ","
+    conan_global_conf += (
+        "tools.system.package_manager:mode=install,"
+        "tools.system.package_manager:sudo=True")
+    os.environ["CONAN_GLOBAL_CONF"] = conan_global_conf
+
+    # Setting values for conan.conf - Client behaviour
+    os.system(f'conan config set storage.download_cache="{tmpdir}"')
+    os.system('conan config set general.revisions_enabled=1')
+
+    conan_docker_entry_script = os.environ.get("CONAN_DOCKER_ENTRY_SCRIPT", '')
+    if conan_docker_entry_script:
+        conan_docker_entry_script += "; "
+    conan_docker_entry_script += (
+        f"conan config set storage.download_cache='{tmpdir}'; "
+        "conan config set general.revisions_enabled=1")
+    os.environ["CONAN_DOCKER_ENTRY_SCRIPT"] = conan_docker_entry_script
+
+    # Docker Run Options
+    conan_docker_run_options = os.environ.get('CONAN_DOCKER_RUN_OPTIONS', '')
+    conan_docker_run_options += f" -v '{tmpdir}':'/tmp/conan'"
+    os.environ['CONAN_DOCKER_RUN_OPTIONS'] = conan_docker_run_options
+
     ###
     # Detect and execute custom build.py file if existing
     ###
@@ -60,46 +142,8 @@ def run_autodetect():
         subprocess.run("python build.py", cwd=new_wd, shell=True, check=True)
         return
 
-    ###
-    # Output collected recipe information in the builds logs
-    ###
-    recipe_is_installer = is_installer()
-    printer.print_message("Is the package an installer for executable(s)? {}"
-                          .format(str(recipe_is_installer)))
-
-    if not recipe_is_installer:
-        recipe_is_unconditional_header_only = is_unconditional_header_only()
-        printer.print_message("Is the package header only? {}"
-                              .format(str(recipe_is_unconditional_header_only)))
-
-        if not recipe_is_unconditional_header_only:
-            recipe_is_conditional_header_only = is_conditional_header_only()
-            printer.print_message("Is the package conditionally header only ('header_only' option)? {}"
-                                  .format(str(recipe_is_conditional_header_only)))
-
-            recipe_is_pure_c = is_pure_c()
-            printer.print_message("Is the package C-only? {}".format(str(recipe_is_pure_c)))
-
-    _flush_output()
-
     ###
     # Start the build
     ###
-    kwargs = {}
-
-    if autodetect_directory_structure() == DIR_STRUCTURE_ONE_RECIPE_MANY_VERSIONS \
-            or autodetect_directory_structure() == DIR_STRUCTURE_CCI:
-        kwargs["stable_branch_pattern"] = os.getenv("CONAN_STABLE_BRANCH_PATTERN", "main")
-
-    if recipe_is_installer:
-        arch = os.getenv("ARCH", "x86_64")
-        builder = build_template_installer.get_builder(**kwargs)
-        builder.add({"os": get_os(), "arch_build": arch, "arch": arch}, {}, {}, {})
-        builder.run()
-    elif recipe_is_unconditional_header_only:
-        builder = build_template_header_only.get_builder(**kwargs)
-        builder.run()
-    else:
-        builder = build_template_default.get_builder(pure_c=recipe_is_pure_c, **kwargs)
-        builder.run()
-
+    builder = _get_builder()
+    builder.run()
