@@ -79,12 +79,9 @@ def is_shared(recipe=None):
 
 def get_repo_name_from_ci():
     reponame_a = os.getenv("APPVEYOR_REPO_NAME", "")
-    reponame_t = os.getenv("TRAVIS_REPO_SLUG", "")
-    reponame_c = "%s/%s" % (os.getenv("CIRCLE_PROJECT_USERNAME", ""),
-                            os.getenv("CIRCLE_PROJECT_REPONAME", ""))
     reponame_azp = os.getenv("BUILD_REPOSITORY_NAME", "")
     reponame_g = os.getenv("GITHUB_REPOSITORY", "")
-    return reponame_a or reponame_t or reponame_c or reponame_azp or reponame_g
+    return reponame_a or reponame_azp or reponame_g
 
 
 def get_repo_branch_from_ci():
@@ -93,8 +90,6 @@ def get_repo_branch_from_ci():
     # in a first attempt (Croydon)
     # ~~Remove GHA special handling after CPT 0.32.0 is released~~
     repobranch_a = os.getenv("APPVEYOR_REPO_BRANCH", "")
-    repobranch_t = os.getenv("TRAVIS_BRANCH", "")
-    repobranch_c = os.getenv("CIRCLE_BRANCH", "")
     repobranch_azp = os.getenv("BUILD_SOURCEBRANCH", "")
     if repobranch_azp.startswith("refs/pull/"):
         repobranch_azp = os.getenv("SYSTEM_PULLREQUEST_TARGETBRANCH", "")
@@ -105,7 +100,7 @@ def get_repo_branch_from_ci():
     if os.getenv("GITHUB_EVENT_NAME", "") == "pull_request":
         repobranch_g = os.getenv("GITHUB_BASE_REF", "")
 
-    return repobranch_a or repobranch_t or repobranch_c or repobranch_azp or repobranch_g
+    return repobranch_a or repobranch_azp or repobranch_g
 
 
 def get_ci_vars():
@@ -172,10 +167,13 @@ def get_conan_vars(recipe=None, kwargs={}):
 
 
 def get_user_repository(username, repository_name):
-    return "https://api.bintray.com/conan/{0}/{1}".format(username.lower(), repository_name)
+    return "https://{0}.jfrog.io/artifactory/api/conan/{1}".format(username.lower(), repository_name)
 
 
 def get_conan_upload(username):
+    if os.getenv("BPT_NO_UPLOAD", "").lower() in ["true", "yes", "on", "1"]:
+        return False
+
     upload = os.getenv("CONAN_UPLOAD")
     if upload:
         return upload.split('@') if '@' in upload else upload
@@ -185,7 +183,13 @@ def get_conan_upload(username):
 
 
 def get_conan_upload_param(username, kwargs):
-    if "upload" not in kwargs:
+    if not get_conan_upload(username):
+        try:
+            del kwargs["upload"]
+        except:
+            pass
+        return kwargs
+    if "upload" not in kwargs and get_conan_upload(username):
         kwargs["upload"] = get_conan_upload(username)
     return kwargs
 
@@ -201,12 +205,13 @@ def get_conan_remotes(username, kwargs):
                     remote = RemotesManager._get_remote_from_str(remote, var_name=remote)
         else:
             # While redundant, this moves upload remote to position 0.
-            remotes = [get_conan_upload(username)]
+            remotes = [get_conan_upload(username)] if get_conan_upload(username) else []
             # Add bincrafters repository for other users, e.g. if the package would
             # require other packages from the bincrafters repo.
             bincrafters_user = BINCRAFTERS_USERNAME
             if username != bincrafters_user:
-                remotes.append(get_conan_upload(bincrafters_user))
+                if get_conan_upload(bincrafters_user):
+                    remotes.append(get_conan_upload(bincrafters_user))
 
             # Force Bincrafters repo on remotes
             if BINCRAFTERS_REPO_URL not in remotes:
